# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`jitsi::client`](#jitsi--client): Install the Jitsi client
* [`jitsi::containerized_server`](#jitsi--containerized_server): Install Jitsi as a containerized service

## Classes

### <a name="jitsi--client"></a>`jitsi::client`

On Linux hosts this class installs the specified version of the standalone
electron client for jitsi as an AppImage package.

#### Examples

##### 

```puppet
include jitsi::client
```

#### Parameters

The following parameters are available in the `jitsi::client` class:

* [`version`](#-jitsi--client--version)
* [`checksum`](#-jitsi--client--checksum)
* [`checksum_type`](#-jitsi--client--checksum_type)

##### <a name="-jitsi--client--version"></a>`version`

Data type: `String`

Which version to install. Find available versions on
https://github.com/jitsi/jitsi-meet-electron/releases.
The default of this parameter gets updated regularly.
When overriding the default make sure you also set the
corresponding values for `checksum` and `checksum_type`.
This is used to ensure you actually downloaded the file
you want to have.

##### <a name="-jitsi--client--checksum"></a>`checksum`

Data type: `String`

Part of the release assets for the Jitsi client is the file
latest-linux.yaml. It contains the checksum and its type.
Note that the checksum is encoded and you have to decode and
convert it:
```
echo $value_from_yaml | base64 -d | xxd -p
```

##### <a name="-jitsi--client--checksum_type"></a>`checksum_type`

Data type: `String`

Which hashing algorithm is used to calculate the checksum of
the AppImage. By default this is sha512.

### <a name="jitsi--containerized_server"></a>`jitsi::containerized_server`

This class downloads definitions from https://github.com/jitsi/docker-jitsi-meet
and performs basic settings to produce a simple working setup of jitsi.
The code in the repository uses docker-compose to start the services as
containers.

#### Examples

##### 

```puppet
include jitsi::containerized_server
```

#### Parameters

The following parameters are available in the `jitsi::containerized_server` class:

* [`http_port`](#-jitsi--containerized_server--http_port)
* [`https_port`](#-jitsi--containerized_server--https_port)
* [`timezone`](#-jitsi--containerized_server--timezone)
* [`public_url`](#-jitsi--containerized_server--public_url)
* [`domain`](#-jitsi--containerized_server--domain)
* [`version`](#-jitsi--containerized_server--version)
* [`jibri_domain`](#-jitsi--containerized_server--jibri_domain)
* [`enable_breakout_rooms`](#-jitsi--containerized_server--enable_breakout_rooms)
* [`disable_all_audio_processing`](#-jitsi--containerized_server--disable_all_audio_processing)
* [`disable_echo_cancellation`](#-jitsi--containerized_server--disable_echo_cancellation)
* [`disable_noise_supression`](#-jitsi--containerized_server--disable_noise_supression)
* [`disable_auto_gain_control`](#-jitsi--containerized_server--disable_auto_gain_control)
* [`disable_high_pass_filter`](#-jitsi--containerized_server--disable_high_pass_filter)
* [`jwt_app_id`](#-jitsi--containerized_server--jwt_app_id)
* [`jwt_app_secret`](#-jitsi--containerized_server--jwt_app_secret)
* [`allow_guests`](#-jitsi--containerized_server--allow_guests)
* [`disable_third_party_requests`](#-jitsi--containerized_server--disable_third_party_requests)
* [`noisy_mic_detection`](#-jitsi--containerized_server--noisy_mic_detection)
* [`video_resolution`](#-jitsi--containerized_server--video_resolution)
* [`start_muted`](#-jitsi--containerized_server--start_muted)
* [`start_without_video`](#-jitsi--containerized_server--start_without_video)
* [`enable_prejoin_page`](#-jitsi--containerized_server--enable_prejoin_page)
* [`enable_simulcast`](#-jitsi--containerized_server--enable_simulcast)
* [`require_display_name`](#-jitsi--containerized_server--require_display_name)
* [`channel_last_n`](#-jitsi--containerized_server--channel_last_n)
* [`custom_variables`](#-jitsi--containerized_server--custom_variables)
* [`compose_jigasi`](#-jitsi--containerized_server--compose_jigasi)
* [`compose_jibri`](#-jitsi--containerized_server--compose_jibri)
* [`compose_etherpad`](#-jitsi--containerized_server--compose_etherpad)

##### <a name="-jitsi--containerized_server--http_port"></a>`http_port`

Data type: `Integer`

Set the port on which you can reach the web frontend via HTTP.
Defaults to 30799.
This is required in particular if you run Jitsi behin a reverse proxy.

##### <a name="-jitsi--containerized_server--https_port"></a>`https_port`

Data type: `Integer`

Set the port on which you can reach the web frontend via HTTPS.
Defaults to 30800.

##### <a name="-jitsi--containerized_server--timezone"></a>`timezone`

Data type: `String`

Set the timezone, your jitsi instance is running in.
Defaults to Europe/Amsterdam.

##### <a name="-jitsi--containerized_server--public_url"></a>`public_url`

Data type: `String`

Set the URL where your users can reach the web frontend.

##### <a name="-jitsi--containerized_server--domain"></a>`domain`

Data type: `String`

FQDN of your jitsi instance.

##### <a name="-jitsi--containerized_server--version"></a>`version`

Data type: `String`

version of the container images used

##### <a name="-jitsi--containerized_server--jibri_domain"></a>`jibri_domain`

Data type: `String`

If using jibri for recording or streaming, it enters the meeting as an additional
user. If it has the domain given in this parameter it will actually be hidden.

##### <a name="-jitsi--containerized_server--enable_breakout_rooms"></a>`enable_breakout_rooms`

Data type: `Boolean`

Enables breakout rooms

##### <a name="-jitsi--containerized_server--disable_all_audio_processing"></a>`disable_all_audio_processing`

Data type: `Boolean`

Set to True if you want to disable all audio processing.
Overrides all of the subsequent parameters.

##### <a name="-jitsi--containerized_server--disable_echo_cancellation"></a>`disable_echo_cancellation`

Data type: `Boolean`

Set to True if you want to disable echo cancellation.

##### <a name="-jitsi--containerized_server--disable_noise_supression"></a>`disable_noise_supression`

Data type: `Boolean`

Set to True if you want to disable noise suppression.

##### <a name="-jitsi--containerized_server--disable_auto_gain_control"></a>`disable_auto_gain_control`

Data type: `Boolean`

Set to True if you want to disable auto gain control.

##### <a name="-jitsi--containerized_server--disable_high_pass_filter"></a>`disable_high_pass_filter`

Data type: `Boolean`

Set to True if you want to disable high pass filtering.

##### <a name="-jitsi--containerized_server--jwt_app_id"></a>`jwt_app_id`

Data type: `String`

Define an id for embedding into jwt based authentication

##### <a name="-jitsi--containerized_server--jwt_app_secret"></a>`jwt_app_secret`

Data type: `String`

Secret for use with JWT authentication

##### <a name="-jitsi--containerized_server--allow_guests"></a>`allow_guests`

Data type: `Integer`

If guests access is allowed

##### <a name="-jitsi--containerized_server--disable_third_party_requests"></a>`disable_third_party_requests`

Data type: `Boolean`

when set to true, no third parties like gravatar will be called (default)

##### <a name="-jitsi--containerized_server--noisy_mic_detection"></a>`noisy_mic_detection`

Data type: `Boolean`

set to false if you want to disable the detection of noisy mics

##### <a name="-jitsi--containerized_server--video_resolution"></a>`video_resolution`

Data type: `Integer`

set the preferred video resolution

##### <a name="-jitsi--containerized_server--start_muted"></a>`start_muted`

Data type: `Boolean`

use this to define if a user shall start muted (true) or with audio enabled (false)

##### <a name="-jitsi--containerized_server--start_without_video"></a>`start_without_video`

Data type: `Boolean`

use this to define if a user shall start without video activatedf (true)

##### <a name="-jitsi--containerized_server--enable_prejoin_page"></a>`enable_prejoin_page`

Data type: `Boolean`

the prejoin page is shown to users right before joining, asking for a name and the audio/video settings.
Set this value to true if you want such a page

##### <a name="-jitsi--containerized_server--enable_simulcast"></a>`enable_simulcast`

Data type: `Boolean`

Unsure about the actual effects.

##### <a name="-jitsi--containerized_server--require_display_name"></a>`require_display_name`

Data type: `Boolean`

Set to true if you require your users to select a name

##### <a name="-jitsi--containerized_server--channel_last_n"></a>`channel_last_n`

Data type: `Integer`

This value can help to save bandwidth on the server. If set to a positive integer,
only this amount of videostreams is sent, representing the last N speakers.

##### <a name="-jitsi--containerized_server--custom_variables"></a>`custom_variables`

Data type: `Optional[Hash[String, Variant[Integer, String, Boolean]]]`

Add custom environment variables which are documented at
https://jitsi.github.io/handbook/docs/devops-guide/devops-guide-docker/

##### <a name="-jitsi--containerized_server--compose_jigasi"></a>`compose_jigasi`

Data type: `Boolean`

Compose and start Jigasi container, the SIP (audio only) gateway.

##### <a name="-jitsi--containerized_server--compose_jibri"></a>`compose_jibri`

Data type: `Boolean`

Compose and start Jibri container, the broadcasting infrastructure.

##### <a name="-jitsi--containerized_server--compose_etherpad"></a>`compose_etherpad`

Data type: `Boolean`

Compose and start Etherpad container, a real-time collaborative editor.

